@@ -1,16 +1,25 @@
 examples_list = [
     'hello_world',
     'foreign_key',
+    'foreign_key_options',
     'many_to_many',
+    'many_to_many_options',
+    'one_to_one',
+    'multiple_foreign_keys',
     'raw_sql',
     'multiple_databases',
     'table_inheritance',
     'write_less_do_more',
 ]
+
 examples_dict = {
     'hello_world': 'Hello World',
-    'foreign_key': 'Foreign Key',
+    'foreign_key': 'Foreign key',
+    'foreign_key_options': 'Foreign key options',
     'many_to_many': 'Many-to-many relationship',
+    'many_to_many_options': 'Many-to-many relationship options',
+    'one_to_one': 'One-to-one relationship',
+    'multiple_foreign_keys': 'Multiple foreign keys',
     'raw_sql': 'Performing raw sql query',
     'multiple_databases': 'Multiple databases',
     'table_inheritance': 'Table inheritance',
