@@ -33,9 +33,7 @@ if __name__ == '__main__':
         content = 'Quick ORM is a python ORM which enables you to get started in less than a minute!')
     comment1 = Comment(user = user2, content = 'good question', post = question)
     comment2 = Comment(user = user2, content = 'nice answer', post = answer)
-
-    database.session.add_all([question, answer, comment1, comment2])
-    database.session.commit()
+    database.session.add_all_then_commit([question, answer, comment1, comment2])
 
     question = database.session.query(Question).get(1)
     print 'new comment on question:', question.comments.first().content
